==> igniteui-react-18.2.2-beta.0.tgz: package/esm5/lib/MaskInputBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { InputBase } from "./InputBase";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var MaskInputBase = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MaskInputBase, _super);
    function MaskInputBase() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(MaskInputBase.prototype, "aa", {
        get: function () {
            var ret_ = this.f.m("prompt");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("prompt", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MaskInputBase.prototype, "z", {
        get: function () {
            var ret_ = this.f.m("invalid");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.u("invalid", value_);
        },
        enumerable: false,
        configurable: true
    });
    MaskInputBase.prototype.ab = function () {
        this.nativeElement.connectedCallback();
    };
    MaskInputBase.prototype.ad = function (a) {
        this.nativeElement.setCustomValidity(this.f.h(a));
    };
    MaskInputBase.prototype.ac = function () {
        this.nativeElement.select();
    };
    MaskInputBase.$t = markType(MaskInputBase, 'MaskInputBase', InputBase.$);
    return MaskInputBase;
}(InputBase));
export { MaskInputBase };

==> igniteui-react-18.3.0-beta.0.tgz: package/esm5/lib/MaskInputBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { InputBase } from "./InputBase";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
var MaskInputBase = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(MaskInputBase, _super);
    function MaskInputBase() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Object.defineProperty(MaskInputBase.prototype, "aa", {
        get: function () {
            var ret_ = this.f.n("prompt");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("prompt", value_);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(MaskInputBase.prototype, "z", {
        get: function () {
            var ret_ = this.f.n("invalid");
            return ret_;
        },
        set: function (a) {
            var value_ = a;
            this.f.v("invalid", value_);
        },
        enumerable: false,
        configurable: true
    });
    MaskInputBase.prototype.ab = function () {
        this.nativeElement.connectedCallback();
    };
    MaskInputBase.prototype.ad = function (a) {
        this.nativeElement.setCustomValidity(this.f.i(a));
    };
    MaskInputBase.prototype.ac = function () {
        this.nativeElement.select();
    };
    MaskInputBase.$t = markType(MaskInputBase, 'MaskInputBase', InputBase.$);
    return MaskInputBase;
}(InputBase));
export { MaskInputBase };
